.. Gumbi documentation master file, created by
   sphinx-quickstart on Fri Jun  4 20:16:53 2021.

Welcome to Gumbi's documentation!
==================================

.. toctree::
   :maxdepth: 1
   :caption: Getting Started:

   notebooks/getting_started/introduction

.. toctree::
   :maxdepth: 2
   :caption: Examples:
   :glob:

   notebooks/examples/Cars_Dataset
   notebooks/examples/Simple_Regression
   notebooks/examples/Multioutput_Regression

.. toctree::
   :maxdepth: 3
   :glob:
   :caption: API:

   gumbi/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
